==> apache-shardingsphere-5.5.2-src.zip: apache-shardingsphere-5.5.2-src-release/features/encrypt/core/src/test/java/org/apache/shardingsphere/encrypt/rewrite/token/pojo/EncryptPredicateInRightValueTokenTest.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.shardingsphere.encrypt.rewrite.token.pojo;

import org.junit.jupiter.api.Test;

import java.util.Collections;
import java.util.LinkedHashMap;
import java.util.Map;

import static org.hamcrest.CoreMatchers.is;
import static org.hamcrest.MatcherAssert.assertThat;

class EncryptPredicateInRightValueTokenTest {
    
    @Test
    void assertToStringWithoutPlaceholderWithoutTableOwnerWithIn() {
        Map<Integer, Object> indexValues = new LinkedHashMap<>(2, 1F);
        indexValues.put(0, "a");
        indexValues.put(1, "b");
        EncryptPredicateInRightValueToken actual = new EncryptPredicateInRightValueToken(0, 0, indexValues, Collections.emptyList());
        assertThat(actual.toString(), is("('a', 'b')"));
    }
    
    @Test
    void assertToStringWithPlaceholderWithoutTableOwnerWithIn() {
        EncryptPredicateInRightValueToken actual = new EncryptPredicateInRightValueToken(0, 0, Collections.emptyMap(), Collections.singleton(0));
        assertThat(actual.toString(), is("(?)"));
    }
}

==> apache-shardingsphere-5.5.3-src.zip: apache-shardingsphere-5.5.3-src-release/features/encrypt/core/src/test/java/org/apache/shardingsphere/encrypt/rewrite/token/pojo/EncryptPredicateInRightValueTokenTest.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.shardingsphere.encrypt.rewrite.token.pojo;

import org.junit.jupiter.api.Test;

import java.util.Collections;
import java.util.LinkedHashMap;
import java.util.Map;

import static org.hamcrest.Matchers.is;
import static org.hamcrest.MatcherAssert.assertThat;

class EncryptPredicateInRightValueTokenTest {
    
    @Test
    void assertToStringWithoutPlaceholderWithoutTableOwnerWithIn() {
        Map<Integer, Object> indexValues = new LinkedHashMap<>(2, 1F);
        indexValues.put(0, "a");
        indexValues.put(1, "b");
        EncryptPredicateInRightValueToken actual = new EncryptPredicateInRightValueToken(0, 0, indexValues, Collections.emptyList());
        assertThat(actual.toString(), is("('a', 'b')"));
    }
    
    @Test
    void assertToStringWithPlaceholderWithoutTableOwnerWithIn() {
        EncryptPredicateInRightValueToken actual = new EncryptPredicateInRightValueToken(0, 0, Collections.emptyMap(), Collections.singleton(0));
        assertThat(actual.toString(), is("(?)"));
    }
}
